# SOTAI

[![](https://img.shields.io/pypi/v/sotai)](https://pypi.org/project/sotai/) [![](https://github.com/SOTAI-Labs/sotai/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/SOTAI-Labs/sotai/actions/workflows/tests.yml)

The new standard in AI interpretability.

SOTAI is:

* **Transparent:** SOTAI combines robust interpretable modeling techniques with supporting analysis tooling to help organizations make faster, well-informed decisions effortlessly.
* **Simple:** Keep it straightforward and avoid unnecessary complexity, just like our approach to AI interpretability.
* **Confidence-Boosting:** With our comprehensive interpretability tools, SOTAI empowers you to trust and act on AI model predictions, enhancing your decision-making confidence.

SOTAI is a Library For Interpretable Machine Learning. This library is a PyTorch implementation of modeling techniques found in [Monotonic Calibrated Interpolated Look-Up Tables](https://jmlr.org/papers/volume17/15-243/15-243.pdf).&#x20;

You can get started in minutes after downloading the package, see our [Quickstart guide](https://docs.sotai.ai/quickstart) or follow along below.

Installing the package:

```shell
pip install sotai
```

Importing the package:

```python
import sotai
```

## SDK Documentation

You can find documentation for this SDK at [https://docs.sotai.ai/v/sdk-ref](https://docs.sotai.ai/v/sdk-ref) or in the repo [docs folder](./).

## Web Client User Documentation

You can find documentation for how to use the hosted web client at [https://docs.sotai.ai/](https://docs.sotai.ai/)

<figure><img src=".gitbook/assets/sdk_code_generator_reduced_whitespace.png" alt=""><figcaption><p>SDK Code Generator</p></figcaption></figure>

<figure><img src=".gitbook/assets/inference_example_analysis_side_by_side.png" alt=""><figcaption><p>Inference Results Side-By-Side Analysis</p></figcaption></figure>

## Contribution Guidelines

See the guide on [contributing](CONTRIBUTING.md) for full details on how to contribute to the library. For any feature and/or bug requests, visit our [Issues](https://github.com/SOTAI-Labs/sotai/issues).

## Examples

For detailed examples on how to use the library, see [examples](https://github.com/SOTAI-Labs/sotai/tree/main/docs/examples).

## Questions and Help

If you have questions about the SOTAI SDK or using the web client, we encourage you to reach out to the community and SOTAI dev team for help.

We actively monitor our [Discord](https://discord.com/invite/YgGuKtqARH) and welcome new community members.

## License

[MIT](../LICENSE/)
